'use client';

import Loading from '@/app/loading';
import { SearchIcon } from '@chakra-ui/icons';
import {
    Box,
    Button,
    Flex,
    Icon,
    Input,
    InputGroup,
    InputLeftElement,
    Text,
    useColorModeValue
} from '@chakra-ui/react';
import React, { useCallback, useState } from 'react';
import { IoRefresh } from 'react-icons/io5';

import Pagination from '../../components/pagination';
import Card from './card';
import { ConsumerInterface } from '../../consumers/type/consumer';

interface CardListComponentProps {
    data?: ConsumerInterface[];
    isLoading?: boolean;
    handleSync: () => void;
}

const CardList: React.FC<CardListComponentProps> = ({ data = [], isLoading = false, handleSync }) => {
    const [searchQuery, setSearchQuery] = useState<string>('');
    const [openCardIndex, setOpenCardIndex] = useState<number | null>(null);
    const [currentPage, setCurrentPage] = useState(1);
    const itemsPerPage = 10;

    const handleSearchChange = (e: React.ChangeEvent<HTMLInputElement>) => {
        setSearchQuery(e.target.value.toLowerCase());
    };

    const toggleCard = useCallback((index: number) => {
        setOpenCardIndex(openCardIndex === index ? null : index);
    }, [openCardIndex]);

    // Filter data based on search query
    const filteredData = Array.isArray(data)
    ? data.filter(
        (item) =>
            item.contact_person?.toLowerCase()?.includes(searchQuery) ||
            item.mobile_no?.includes(searchQuery) ||
            item.paid_amount?.includes(searchQuery) ||
            item.meter_reading?.includes(searchQuery)
        )
    : [];

    const startIndex = (currentPage - 1) * itemsPerPage;
    const endIndex = startIndex + itemsPerPage;
    const currentData = filteredData.slice(startIndex, endIndex);

    // Handle page changes
    const handlePageChange = (newPage: number) => {
        setCurrentPage(newPage);
    };

    const totalPages = Math.ceil(filteredData.length / itemsPerPage);

    return (
        <>
            <Flex alignItems="center" justifyContent="space-between">
                <InputGroup width="300px">
                    <InputLeftElement pointerEvents="none">
                        <SearchIcon color={useColorModeValue('black', 'white')} />
                    </InputLeftElement>
                    <Input
                        placeholder="Search..."
                        variant="outline"
                        focusBorderColor="blue.500"
                        size="md"
                        type="search"
                        color={useColorModeValue('black', 'white')}
                        onChange={handleSearchChange}
                    />
                </InputGroup>
            </Flex >
            <br />
            {
                isLoading ? (
                    <Loading />
                ) : (
                    <>
                        {currentData?.length > 0 ? (
                            currentData?.map((consumer, index) => (
                                <Card
                                    key={index}
                                    consumer={consumer}
                                    isOpen={openCardIndex === index}
                                    onToggle={() => toggleCard(index)}
                                    fetch={handleSync}
                                />
                            ))
                        ) : (
                            <Box mt="30px" display="flex" justifyContent="center">
                                <Text>No Data Found</Text>
                            </Box>
                        )}
                    </>
                )
            }


            {
                !isLoading && totalPages > 1 && (
                    <Pagination
                        currentPage={currentPage}
                        totalPages={totalPages}
                        onPageChange={handlePageChange}
                    />
                )
            }
        </>
    );
};

export default CardList;




